@@ -663,7 +663,7 @@ static int njGetVLC(nj_vlc_code_t* vlc, unsigned char* code) {
     if (!bits) return 0;
     value = njGetBits(bits);
     if (value < (1 << (bits - 1)))
-        value += shiftLeft(-1, bits) + 1;
+        value += (shiftLeft(-1, bits)) + 1;
     return value;
 }
 
